@@ -9,8 +9,6 @@
 #                                                           #
 #############################################################
 import mb_cgi
-import Mobyle.ConfigManager
-import urllib # module used to encode the anchors in the menu html page
 from Mobyle.Registry import registry
 from Mobyle.ClassificationIndex import ClassificationIndex
 from Mobyle.SearchIndex import SearchIndex
@@ -19,23 +17,27 @@ from Mobyle.DescriptionsIndex import DescriptionsIndex
 
 def process(self):
     self.template_file = "programs_list.html"
-    isInPortal = self.request.getfirst('isInPortal', 'false')
-    self.response['sortBy'] = self.request.getfirst('sortBy', 'server')
     self.response['filterOn'] = 'false'
     self.response['emptySearchResults'] = 'false'
 
     if self.request.getfirst('plSubmit')=='Search':
         searchString = self.request.getfirst('searchString',None)
         if searchString:
-            si = SearchIndex()
             self.response['filterOn'] = 'true'
+            si = SearchIndex("program")
             si.filterRegistry(searchString.split(' '))
-        if len(registry.programs)==0:
+            sj = SearchIndex("workflow")
+            sj.filterRegistry(searchString.split(' '))
+        if len(registry.programs)+len(registry.workflows)==0:
             self.response['emptySearchResults'] = 'true'
 
-    classification = ClassificationIndex()
-    DescriptionsIndex().fillRegistry()
-    classification.buildRegistryCategories()
+    p_classification = ClassificationIndex("program")
+    w_classification = ClassificationIndex("workflow")
+    DescriptionsIndex("program").fillRegistry()
+    DescriptionsIndex("workflow").fillRegistry()
+    p_classification.buildRegistryCategories(field=self.request.getfirst('classifyBy','category'),serviceTypeSort=self.request.getfirst('serviceTypeSort','separate'))
+    w_classification.buildRegistryCategories(field=self.request.getfirst('classifyBy','category'),serviceTypeSort=self.request.getfirst('serviceTypeSort','separate'))
+    registry.servers.sort()
     self.response['registry']=registry
       
 if __name__ == "__main__":
